@@ -22,7 +22,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <libgda/gda-data-model-array.h>
 #include <libgda/gda-intl.h>
 #include <stdlib.h>
@@ -184,7 +183,8 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
         const gchar *t_password = NULL;
         const gchar *t_port = NULL;
         const gchar *t_unix_socket = NULL;
-        const gchar *t_flags = NULL;
+        const gchar *t_use_ssl = NULL;
+	unsigned int mysqlflags = 0;
 	MYSQL *mysql;
 #if MYSQL_VERSION_ID < 32200
         gint err;
@@ -198,17 +198,20 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
 	/* get all parameters received */
 	t_host = gda_quark_list_find (params, "HOST");
 	t_db = gda_quark_list_find (params, "DATABASE");
-	t_user = gda_quark_list_find (params, "USERNAME");
+	t_user = gda_quark_list_find (params, "USER");
 	t_password = gda_quark_list_find (params, "PASSWORD");
 	t_port = gda_quark_list_find (params, "PORT");
 	t_unix_socket = gda_quark_list_find (params, "UNIX_SOCKET");
-	t_flags = gda_quark_list_find (params, "FLAGS");
+	t_use_ssl = gda_quark_list_find (params, "USE_SSL");
 
 	if (username)
 		t_user = username;
 	if (password)
 		t_password = password;
 
+	if (t_use_ssl && atoi (t_use_ssl) == 1)
+		mysqlflags |= CLIENT_SSL;
+
 	/* we can't have both a host/pair AND a unix_socket */
 	if ((t_host || t_port) && t_unix_socket) {
 		gda_connection_add_error_string (
@@ -219,20 +222,21 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
 
 	/* provide the default of localhost:3306 if neither is provided */
 	if (!t_unix_socket) {
-		if (!t_port)
-			t_port = "3306";
 		if (!t_host)
 			t_host = "localhost";
+		else if (!t_port)
+			t_port = "3306";
 	}
-
+	
 	mysql = g_new0 (MYSQL, 1);
+	mysql_init (mysql);
 	mysql = mysql_real_connect (mysql, t_host, t_user, t_password,
 #if MYSQL_VERSION_ID >= 32200
 				    t_db,
 #endif
 				    t_port ? atoi (t_port) : 0,
 				    t_unix_socket,
-				    t_flags ? atoi (t_flags) : 0);
+				    mysqlflags);
 	if (!mysql) {
 		error = gda_mysql_make_error (mysql);
 		gda_connection_add_error (cnc, error);
@@ -299,6 +303,7 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 {
 	MYSQL *mysql;
 	gchar **arr;
+	GdaConnectionOptions options;
 
 	mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
 	if (!mysql) {
@@ -306,6 +311,8 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 		return NULL;
 	}
 
+	options = gda_connection_get_options (cnc);
+
 	/* parse SQL string, which can contain several commands, separated by ';' */
 	arr = g_strsplit (sql, ";", 0);
 	if (arr) {
@@ -316,6 +323,24 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 			MYSQL_RES *mysql_res;
 			GdaMysqlRecordset *recset;
 
+			/* if the connection is in read-only mode, just allow SELECT,
+			   SHOW commands */
+			if (options & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+				gchar *s;
+
+				/* FIXME: maybe there's a better way of doing this? */
+				s = g_strstrip (g_strdup (arr[n]));
+				if (g_ascii_strncasecmp (s, "select", strlen ("select")) &&
+				    g_ascii_strncasecmp (s, "show", strlen ("show"))) {
+					gda_connection_add_error_string (
+						cnc, "Command '%s' cannot be executed in read-only mode", arr[n]);
+					break;
+				}
+
+				g_free (s);
+			}
+
+			/* execute the command on the server */
 			rc = mysql_real_query (mysql, arr[n], strlen (arr[n]));
 			if (rc != 0) {
 				gda_connection_add_error (cnc, gda_mysql_make_error (mysql));
@@ -323,7 +348,7 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 			}
 
 			mysql_res = mysql_store_result (mysql);
-			recset = gda_mysql_recordset_new (cnc, mysql_res);
+			recset = gda_mysql_recordset_new (cnc, mysql_res, mysql);
 			if (GDA_IS_MYSQL_RECORDSET (recset)) {
 				gda_data_model_set_command_text (recset, arr[n]);
 				gda_data_model_set_command_type (recset, GDA_COMMAND_TYPE_SQL);
@@ -510,6 +535,11 @@ gda_mysql_provider_begin_transaction (GdaServerProvider *provider,
 		return FALSE;
 	}
 
+	if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+		gda_connection_add_error_string (cnc, _("Transactions are not supported in read-only mode"));
+		return FALSE;
+	}
+
 	/* set isolation level */
 	switch (gda_transaction_get_isolation_level (xaction)) {
 	case GDA_TRANSACTION_ISOLATION_READ_COMMITTED :
@@ -562,6 +592,11 @@ gda_mysql_provider_commit_transaction (GdaServerProvider *provider,
 		return FALSE;
 	}
 
+	if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+		gda_connection_add_error_string (cnc, _("Transactions are not supported in read-only mode"));
+		return FALSE;
+	}
+
 	rc = mysql_real_query (mysql, "COMMIT", strlen ("COMMIT"));
 	if (rc != 0) {
 		gda_connection_add_error (cnc, gda_mysql_make_error (mysql));
@@ -590,6 +625,11 @@ gda_mysql_provider_rollback_transaction (GdaServerProvider *provider,
 		return FALSE;
 	}
 
+	if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+		gda_connection_add_error_string (cnc, _("Transactions are not supported in read-only mode"));
+		return FALSE;
+	}
+
 	rc = mysql_real_query (mysql, "ROLLBACK", strlen ("ROLLBACK"));
 	if (rc != 0) {
 		gda_connection_add_error (cnc, gda_mysql_make_error (mysql));
@@ -621,21 +661,32 @@ gda_mysql_provider_supports (GdaServerProvider *provider,
 }
 
 static void
-add_aggregate_row (GdaDataModelArray *recset, const gchar *str)
+add_aggregate_row (GdaDataModelArray *recset, const gchar *str, const gchar *comments)
 {
 	GdaValue *value;
-	GList list;
+	GList *list;
 
 	g_return_if_fail (GDA_IS_DATA_MODEL_ARRAY (recset));
 
-	value = gda_value_new_string (str);
-	list.data = value;
-	list.next = NULL;
-	list.prev = NULL;
+	/* 1st the name */
+	list = g_list_append (NULL, gda_value_new_string (str));
+	/* 2nd the unique id */
+	list = g_list_append (list, gda_value_new_string (str));
+	/* 3rd the owner */
+	list = g_list_append (list, gda_value_new_string (NULL));
+	/* 4th the comments */ 
+	list = g_list_append (list, gda_value_new_string (comments));
+	/* 5th the return type */
+	list = g_list_append (list, gda_value_new_string (gda_type_to_string (GDA_VALUE_TYPE_UNKNOWN)));
+	/* 6th the argument type */
+	list = g_list_append (list, gda_value_new_string (gda_type_to_string (GDA_VALUE_TYPE_UNKNOWN)));
+	/* 7th the SQL definition */
+	list = g_list_append (list, gda_value_new_string (NULL));
 
-	gda_data_model_append_row (GDA_DATA_MODEL (recset), &list);
+	gda_data_model_append_row (GDA_DATA_MODEL (recset), list);
 
-	gda_value_free (value);
+	g_list_foreach (list, gda_value_free, NULL);
+	g_list_free (list);
 }
 
 static GdaDataModel *
@@ -646,149 +697,152 @@ get_mysql_aggregates (GdaConnection *cnc, GdaParameterList *params)
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
 	/* create the recordset */
-	recset = (GdaDataModelArray *) gda_data_model_array_new (1);
-	//gda_server_recordset_model_set_field_defined_size (recset, 0, 32);
+	recset = (GdaDataModelArray *) gda_data_model_array_new (7);
 	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 0, _("Name"));
-	//gda_server_recordset_model_set_field_scale (recset, 0, 0);
-	//gda_server_recordset_model_set_field_gdatype (recset, 0, GDA_TYPE_STRING);
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 1, _("ID"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 2, _("Owner"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 3, _("Comments"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 4, _("Return type"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 5, _("Args types"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 6, _("SQL"));
 
 	/* fill the recordset */
-	add_aggregate_row (recset, "abs");
-	add_aggregate_row (recset, "acos");
-	add_aggregate_row (recset, "adddate");
-	add_aggregate_row (recset, "ascii");
-	add_aggregate_row (recset, "asin");
-	add_aggregate_row (recset, "atan");
-	add_aggregate_row (recset, "atan2");
-	add_aggregate_row (recset, "benchmark");
-	add_aggregate_row (recset, "bin");
-	add_aggregate_row (recset, "bit_count");
-	add_aggregate_row (recset, "ceiling");
-	add_aggregate_row (recset, "char");
-	add_aggregate_row (recset, "char_length");
-	add_aggregate_row (recset, "character_length");
-	add_aggregate_row (recset, "coalesce");
-	add_aggregate_row (recset, "concat");
-	add_aggregate_row (recset, "concat_ws");
-	add_aggregate_row (recset, "connection_id");
-	add_aggregate_row (recset, "conv");
-	add_aggregate_row (recset, "cos");
-	add_aggregate_row (recset, "cot");
-	add_aggregate_row (recset, "count");
-	add_aggregate_row (recset, "curdate");
-	add_aggregate_row (recset, "current_date");
-	add_aggregate_row (recset, "current_time");
-	add_aggregate_row (recset, "current_timestamp");
-	add_aggregate_row (recset, "curtime");
-	add_aggregate_row (recset, "database");
-	add_aggregate_row (recset, "date_add");
-	add_aggregate_row (recset, "date_format");
-	add_aggregate_row (recset, "date_sub");
-	add_aggregate_row (recset, "dayname");
-	add_aggregate_row (recset, "dayofmonth");
-	add_aggregate_row (recset, "dayofweek");
-	add_aggregate_row (recset, "dayofyear");
-	add_aggregate_row (recset, "decode");
-	add_aggregate_row (recset, "degrees");
-	add_aggregate_row (recset, "elt");
-	add_aggregate_row (recset, "encode");
-	add_aggregate_row (recset, "encrypt");
-	add_aggregate_row (recset, "exp");
-	add_aggregate_row (recset, "export_set");
-	add_aggregate_row (recset, "extract");
-	add_aggregate_row (recset, "field");
-	add_aggregate_row (recset, "find_in_set");
-	add_aggregate_row (recset, "floor");
-	add_aggregate_row (recset, "format");
-	add_aggregate_row (recset, "from_days");
-	add_aggregate_row (recset, "from_unixtime");
-	add_aggregate_row (recset, "get_lock");
-	add_aggregate_row (recset, "greatest");
-	add_aggregate_row (recset, "hex");
-	add_aggregate_row (recset, "hour");
-	add_aggregate_row (recset, "if");
-	add_aggregate_row (recset, "ifnull");
-	add_aggregate_row (recset, "inet_aton");
-	add_aggregate_row (recset, "inet_ntoa");
-	add_aggregate_row (recset, "insert");
-	add_aggregate_row (recset, "instr");
-	add_aggregate_row (recset, "interval");
-	add_aggregate_row (recset, "isnull");
-	add_aggregate_row (recset, "last_insert_id");
-	add_aggregate_row (recset, "lcase");
-	add_aggregate_row (recset, "least");
-	add_aggregate_row (recset, "left");
-	add_aggregate_row (recset, "length");
-	add_aggregate_row (recset, "load_file");
-	add_aggregate_row (recset, "locate");
-	add_aggregate_row (recset, "log");
-	add_aggregate_row (recset, "log10");
-	add_aggregate_row (recset, "lower");
-	add_aggregate_row (recset, "lpad");
-	add_aggregate_row (recset, "ltrim");
-	add_aggregate_row (recset, "make_set");
-	add_aggregate_row (recset, "master_pos_wait");
-	add_aggregate_row (recset, "match");
-	add_aggregate_row (recset, "max");
-	add_aggregate_row (recset, "md5");
-	add_aggregate_row (recset, "mid");
-	add_aggregate_row (recset, "min");
-	add_aggregate_row (recset, "minute");
-	add_aggregate_row (recset, "mod");
-	add_aggregate_row (recset, "month");
-	add_aggregate_row (recset, "monthname");
-	add_aggregate_row (recset, "now");
-	add_aggregate_row (recset, "nullif");
-	add_aggregate_row (recset, "oct");
-	add_aggregate_row (recset, "octet_length");
-	add_aggregate_row (recset, "ord");
-	add_aggregate_row (recset, "password");
-	add_aggregate_row (recset, "period_add");
-	add_aggregate_row (recset, "period_diff");
-	add_aggregate_row (recset, "pi");
-	add_aggregate_row (recset, "position");	
-	add_aggregate_row (recset, "pow");
-	add_aggregate_row (recset, "power");
-	add_aggregate_row (recset, "quarter");
-	add_aggregate_row (recset, "radians");
-	add_aggregate_row (recset, "rand");
-	add_aggregate_row (recset, "release_lock");
-	add_aggregate_row (recset, "repeat");
-	add_aggregate_row (recset, "replace");	
-	add_aggregate_row (recset, "reverse");
-	add_aggregate_row (recset, "right");
-	add_aggregate_row (recset, "round");
-	add_aggregate_row (recset, "rpad");
-	add_aggregate_row (recset, "rtrim");
-	add_aggregate_row (recset, "second");
-	add_aggregate_row (recset, "sec_to_time");
-	add_aggregate_row (recset, "session_user");
-	add_aggregate_row (recset, "sign");
-	add_aggregate_row (recset, "sin");
-	add_aggregate_row (recset, "soundex");
-	add_aggregate_row (recset, "space");
-	add_aggregate_row (recset, "sqrt");
-	add_aggregate_row (recset, "strcmp");
-	add_aggregate_row (recset, "subdate");
-	add_aggregate_row (recset, "substring");
-	add_aggregate_row (recset, "substring_index");
-	add_aggregate_row (recset, "sysdate");
-	add_aggregate_row (recset, "system_user");
-	add_aggregate_row (recset, "tan");
-	add_aggregate_row (recset, "time_format");
-	add_aggregate_row (recset, "time_to_sec");
-	add_aggregate_row (recset, "to_days");
-	add_aggregate_row (recset, "trim");
-	add_aggregate_row (recset, "truncate");
-	add_aggregate_row (recset, "ucase");
-	add_aggregate_row (recset, "unix_timestamp");
-	add_aggregate_row (recset, "upper");
-	add_aggregate_row (recset, "user");
-	add_aggregate_row (recset, "version");
-	add_aggregate_row (recset, "week");
-	add_aggregate_row (recset, "weekday");
-	add_aggregate_row (recset, "year");
-	add_aggregate_row (recset, "yearweek");
+	add_aggregate_row (recset, "abs", "comments");
+	add_aggregate_row (recset, "acos", "comments");
+	add_aggregate_row (recset, "adddate", "comments");
+	add_aggregate_row (recset, "ascii", "comments");
+	add_aggregate_row (recset, "asin", "comments");
+	add_aggregate_row (recset, "atan", "comments");
+	add_aggregate_row (recset, "atan2", "comments");
+	add_aggregate_row (recset, "benchmark", "comments");
+	add_aggregate_row (recset, "bin", "comments");
+	add_aggregate_row (recset, "bit_count", "comments");
+	add_aggregate_row (recset, "ceiling", "comments");
+	add_aggregate_row (recset, "char", "comments");
+	add_aggregate_row (recset, "char_length", "comments");
+	add_aggregate_row (recset, "character_length", "comments");
+	add_aggregate_row (recset, "coalesce", "comments");
+	add_aggregate_row (recset, "concat", "comments");
+	add_aggregate_row (recset, "concat_ws", "comments");
+	add_aggregate_row (recset, "connection_id", "comments");
+	add_aggregate_row (recset, "conv", "comments");
+	add_aggregate_row (recset, "cos", "comments");
+	add_aggregate_row (recset, "cot", "comments");
+	add_aggregate_row (recset, "count", "comments");
+	add_aggregate_row (recset, "curdate", "comments");
+	add_aggregate_row (recset, "current_date", "comments");
+	add_aggregate_row (recset, "current_time", "comments");
+	add_aggregate_row (recset, "current_timestamp", "comments");
+	add_aggregate_row (recset, "curtime", "comments");
+	add_aggregate_row (recset, "database", "comments");
+	add_aggregate_row (recset, "date_add", "comments");
+	add_aggregate_row (recset, "date_format", "comments");
+	add_aggregate_row (recset, "date_sub", "comments");
+	add_aggregate_row (recset, "dayname", "comments");
+	add_aggregate_row (recset, "dayofmonth", "comments");
+	add_aggregate_row (recset, "dayofweek", "comments");
+	add_aggregate_row (recset, "dayofyear", "comments");
+	add_aggregate_row (recset, "decode", "comments");
+	add_aggregate_row (recset, "degrees", "comments");
+	add_aggregate_row (recset, "elt", "comments");
+	add_aggregate_row (recset, "encode", "comments");
+	add_aggregate_row (recset, "encrypt", "comments");
+	add_aggregate_row (recset, "exp", "comments");
+	add_aggregate_row (recset, "export_set", "comments");
+	add_aggregate_row (recset, "extract", "comments");
+	add_aggregate_row (recset, "field", "comments");
+	add_aggregate_row (recset, "find_in_set", "comments");
+	add_aggregate_row (recset, "floor", "comments");
+	add_aggregate_row (recset, "format", "comments");
+	add_aggregate_row (recset, "from_days", "comments");
+	add_aggregate_row (recset, "from_unixtime", "comments");
+	add_aggregate_row (recset, "get_lock", "comments");
+	add_aggregate_row (recset, "greatest", "comments");
+	add_aggregate_row (recset, "hex", "comments");
+	add_aggregate_row (recset, "hour", "comments");
+	add_aggregate_row (recset, "if", "comments");
+	add_aggregate_row (recset, "ifnull", "comments");
+	add_aggregate_row (recset, "inet_aton", "comments");
+	add_aggregate_row (recset, "inet_ntoa", "comments");
+	add_aggregate_row (recset, "insert", "comments");
+	add_aggregate_row (recset, "instr", "comments");
+	add_aggregate_row (recset, "interval", "comments");
+	add_aggregate_row (recset, "isnull", "comments");
+	add_aggregate_row (recset, "last_insert_id", "comments");
+	add_aggregate_row (recset, "lcase", "comments");
+	add_aggregate_row (recset, "least", "comments");
+	add_aggregate_row (recset, "left", "comments");
+	add_aggregate_row (recset, "length", "comments");
+	add_aggregate_row (recset, "load_file", "comments");
+	add_aggregate_row (recset, "locate", "comments");
+	add_aggregate_row (recset, "log", "comments");
+	add_aggregate_row (recset, "log10", "comments");
+	add_aggregate_row (recset, "lower", "comments");
+	add_aggregate_row (recset, "lpad", "comments");
+	add_aggregate_row (recset, "ltrim", "comments");
+	add_aggregate_row (recset, "make_set", "comments");
+	add_aggregate_row (recset, "master_pos_wait", "comments");
+	add_aggregate_row (recset, "match", "comments");
+	add_aggregate_row (recset, "max", "comments");
+	add_aggregate_row (recset, "md5", "comments");
+	add_aggregate_row (recset, "mid", "comments");
+	add_aggregate_row (recset, "min", "comments");
+	add_aggregate_row (recset, "minute", "comments");
+	add_aggregate_row (recset, "mod", "comments");
+	add_aggregate_row (recset, "month", "comments");
+	add_aggregate_row (recset, "monthname", "comments");
+	add_aggregate_row (recset, "now", "comments");
+	add_aggregate_row (recset, "nullif", "comments");
+	add_aggregate_row (recset, "oct", "comments");
+	add_aggregate_row (recset, "octet_length", "comments");
+	add_aggregate_row (recset, "ord", "comments");
+	add_aggregate_row (recset, "password", "comments");
+	add_aggregate_row (recset, "period_add", "comments");
+	add_aggregate_row (recset, "period_diff", "comments");
+	add_aggregate_row (recset, "pi", "comments");
+	add_aggregate_row (recset, "position", "comments");	
+	add_aggregate_row (recset, "pow", "comments");
+	add_aggregate_row (recset, "power", "comments");
+	add_aggregate_row (recset, "quarter", "comments");
+	add_aggregate_row (recset, "radians", "comments");
+	add_aggregate_row (recset, "rand", "comments");
+	add_aggregate_row (recset, "release_lock", "comments");
+	add_aggregate_row (recset, "repeat", "comments");
+	add_aggregate_row (recset, "replace", "comments");	
+	add_aggregate_row (recset, "reverse", "comments");
+	add_aggregate_row (recset, "right", "comments");
+	add_aggregate_row (recset, "round", "comments");
+	add_aggregate_row (recset, "rpad", "comments");
+	add_aggregate_row (recset, "rtrim", "comments");
+	add_aggregate_row (recset, "second", "comments");
+	add_aggregate_row (recset, "sec_to_time", "comments");
+	add_aggregate_row (recset, "session_user", "comments");
+	add_aggregate_row (recset, "sign", "comments");
+	add_aggregate_row (recset, "sin", "comments");
+	add_aggregate_row (recset, "soundex", "comments");
+	add_aggregate_row (recset, "space", "comments");
+	add_aggregate_row (recset, "sqrt", "comments");
+	add_aggregate_row (recset, "strcmp", "comments");
+	add_aggregate_row (recset, "subdate", "comments");
+	add_aggregate_row (recset, "substring", "comments");
+	add_aggregate_row (recset, "substring_index", "comments");
+	add_aggregate_row (recset, "sysdate", "comments");
+	add_aggregate_row (recset, "system_user", "comments");
+	add_aggregate_row (recset, "tan", "comments");
+	add_aggregate_row (recset, "time_format", "comments");
+	add_aggregate_row (recset, "time_to_sec", "comments");
+	add_aggregate_row (recset, "to_days", "comments");
+	add_aggregate_row (recset, "trim", "comments");
+	add_aggregate_row (recset, "truncate", "comments");
+	add_aggregate_row (recset, "ucase", "comments");
+	add_aggregate_row (recset, "unix_timestamp", "comments");
+	add_aggregate_row (recset, "upper", "comments");
+	add_aggregate_row (recset, "user", "comments");
+	add_aggregate_row (recset, "version", "comments");
+	add_aggregate_row (recset, "week", "comments");
+	add_aggregate_row (recset, "weekday", "comments");
+	add_aggregate_row (recset, "year", "comments");
+	add_aggregate_row (recset, "yearweek", "comments");
 
 	return GDA_DATA_MODEL (recset);
 }
@@ -832,6 +886,10 @@ get_mysql_tables (GdaConnection *cnc, GdaParameterList *params)
 
 	/* add the extra information */
 	model = gda_data_model_array_new (4);
+	gda_data_model_set_column_title (GDA_DATA_MODEL (model), 0, _("Name"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (model), 1, _("Owner"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (model), 2, _("Comments"));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (model), 3, "SQL");
 	rows = gda_data_model_get_n_rows (GDA_DATA_MODEL (recset));
 	for (r = 0; r < rows; r++) {
 		GList *value_list = NULL;
@@ -1060,14 +1118,18 @@ get_table_fields (GdaConnection *cnc, GdaParameterList *params)
 	/* fill in the recordset to be returned */
 	recset = (GdaDataModelArray *) gda_data_model_array_new (9);
 	for (r = 0; r < sizeof (fields_desc) / sizeof (fields_desc[0]); r++) {
-		//gint defined_size =  (fields_desc[r].type == GDA_VALUE_TYPE_STRING) ? 64 : 
-		//	(fields_desc[r].type == GDA_VALUE_TYPE_INTEGER) ? sizeof (gint) : 1;
+/*
+		gint defined_size =  (fields_desc[r].type == GDA_VALUE_TYPE_STRING) ? 64 : 
+			(fields_desc[r].type == GDA_VALUE_TYPE_INTEGER) ? sizeof (gint) : 1;
+*/
 
-		//gda_server_recordset_model_set_field_defined_size (recset, r, defined_size);
+		/* gda_server_recordset_model_set_field_defined_size (recset, r, defined_size); */
 		gda_data_model_set_column_title (GDA_DATA_MODEL (recset), r,
 						_(fields_desc[r].name));
-		//gda_server_recordset_model_set_field_scale (recset, r, 0);
-		//gda_server_recordset_model_set_field_gdatype (recset, r, fields_desc[r].type);
+/*
+		gda_server_recordset_model_set_field_scale (recset, r, 0);
+		gda_server_recordset_model_set_field_gdatype (recset, r, fields_desc[r].type);
+*/
 	}
 	
 	for (r = 0; r < rows; r++) {
